@@ -12,10 +12,24 @@ class DefaultTestSetupMixin:
     verbose = True
 
     def debug_print(self, *args, **kw):
+        """
+        print() only on verbose=True or self.verbose
+        :param args:
+        :param kw:
+        :return:
+        """
         if kw.pop('verbose', self.verbose):
             print(*args)
 
     def request(self, method: str, path: str, data: dict, **kw) -> Tuple[dict, int]:
+        """
+        API client request.
+        :param method:
+        :param path:
+        :param data:
+        :param kw:
+        :return:
+        """
         verbose = kw.pop('verbose', self.verbose)
         self.debug_print('HTTP {} {} {}'.format(method.upper(), path, data), verbose=verbose)
         # print('HTTP {method} {data}'.format(method=method.upper(), data=data))
@@ -26,30 +40,65 @@ class DefaultTestSetupMixin:
         return reply, res.status_code
 
     def post(self, path: str, data: dict, **kw) -> dict:
+        """
+        API client POST
+        :param path:
+        :param data:
+        :param kw:
+        :return:
+        """
         reply, status_code = self.request('post', path, data, **kw)
         if status_code >= 300:
             raise Exception('HTTP {} {} {}: {} {}'.format('POST', status_code, path, data, reply))
         return reply
 
     def get(self, path: str, data: dict, **kw) -> dict:
+        """
+        API client GET
+        :param path:
+        :param data:
+        :param kw:
+        :return:
+        """
         reply, status_code = self.request('get', path, data, **kw)
         if status_code >= 300:
             raise Exception('HTTP {} {} {}: {} {}'.format('GET', status_code, path, data, reply))
         return reply
 
     def put(self, path: str, data: dict, **kw) -> dict:
+        """
+        API client PUT
+        :param path:
+        :param data:
+        :param kw:
+        :return:
+        """
         reply, status_code = self.request('put', path, data, **kw)
         if status_code >= 300:
             raise Exception('HTTP {} {} {}: {} {}'.format('PUT', status_code, path, data, reply))
         return reply
 
     def patch(self, path: str, data: dict, **kw) -> dict:
+        """
+        API client PATCH
+        :param path:
+        :param data:
+        :param kw:
+        :return:
+        """
         reply, status_code = self.request('patch', path, data, **kw)
         if status_code >= 300:
             raise Exception('HTTP {} {} {}: {} {}'.format('PATCH', status_code, path, data, reply))
         return reply
 
     def delete(self, path: str, data: dict, **kw) -> dict:
+        """
+        API client DELETE
+        :param path:
+        :param data:
+        :param kw:
+        :return:
+        """
         reply, status_code = self.request('delete', path, data, **kw)
         if status_code >= 300:
             raise Exception('HTTP {} {} {}: {} {}'.format('DELETE', status_code, path, data, reply))
@@ -62,7 +111,14 @@ class DefaultTestSetupMixin:
         :param password:
         :return:
         """
-        self.user = User.objects.create_user(email, email, password)  # type: ignore
+        self.user = User.objects.filter(username=email).first()
+        if self.user is None:
+            self.user = User.objects.create_user(email, email, password)  # type: ignore
+        user = self.user
+        assert isinstance(user, User)
+        user.set_password(password)
+        user.save()
         self.token = Token.objects.get_or_create(user=self.user)[0]
         self.api_client = APIClient()
         self.api_client.credentials(HTTP_AUTHORIZATION='Token {}'.format(self.token.key))
+        return self.user
